@@ -271,7 +271,8 @@ enum cnffuncid {
 	CNFFUNC_LOOKUP,
 	CNFFUNC_EXEC_TEMPLATE,
 	CNFFUNC_REPLACE,
-	CNFFUNC_WRAP
+	CNFFUNC_WRAP,
+	CNFFUNC_RANDOM
 };
 
 struct cnffunc {
@@ -358,10 +359,10 @@ int cnfDoInclude(char *name);
 int cnfparamGetIdx(struct cnfparamblk *params, char *name);
 struct cnfparamvals* nvlstGetParams(struct nvlst *lst, struct cnfparamblk *params,
 	       struct cnfparamvals *vals);
-void cnfparamsPrint(struct cnfparamblk *params, struct cnfparamvals *vals);
+void cnfparamsPrint(const struct cnfparamblk *params, const struct cnfparamvals *vals);
 int cnfparamvalsIsSet(struct cnfparamblk *params, struct cnfparamvals *vals);
-void varDelete(struct var *v);
-void cnfparamvalsDestruct(struct cnfparamvals *paramvals, struct cnfparamblk *blk);
+void varDelete(const struct var *v);
+void cnfparamvalsDestruct(const struct cnfparamvals *paramvals, const struct cnfparamblk *blk);
 struct cnfstmt * cnfstmtNew(unsigned s_type);
 struct cnfitr * cnfNewIterator(char *var, struct cnfexpr *collection);
 void cnfstmtPrintOnly(struct cnfstmt *stmt, int indent, sbool subtree);
