@@ -453,6 +453,8 @@ rsRetVal parsAddrWithBits(rsParsObj *pThis, struct NetAddr **pIP, int *pBits)
 			/* mask bits follow, let's parse them! */
 			++pThis->iCurrPos; /* eat slash */
 			if((iRet = parsInt(pThis, pBits)) != RS_RET_OK) {
+				free((*pIP)->addr.NetAddr);
+				free((*pIP)->addr.HostWildcard);
 				free (pszIP);
 				free (*pIP);
 				FINALIZE;
@@ -489,6 +491,8 @@ rsRetVal parsAddrWithBits(rsParsObj *pThis, struct NetAddr **pIP, int *pBits)
 			/* mask bits follow, let's parse them! */
 			++pThis->iCurrPos; /* eat slash */
 			if((iRet = parsInt(pThis, pBits)) != RS_RET_OK) {
+				free((*pIP)->addr.NetAddr);
+				free((*pIP)->addr.HostWildcard);
 				free (pszIP);
 				free (*pIP);
 				FINALIZE;
