@@ -75,6 +75,7 @@ MODULE_CNFNAME("imuxsock")
 #ifndef SYSTEMD_PATH_LOG
 #define SYSTEMD_PATH_LOG SYSTEMD_JOURNAL "/syslog"
 #endif
+#define UNSET -1 /* to indicate a value has not been configured */
 
 /* forward definitions */
 static rsRetVal resetConfigVariables(uchar __attribute__((unused)) *pp, void __attribute__((unused)) *pVal);
@@ -146,6 +147,7 @@ typedef struct lstn_s {
 	sbool bDiscardOwnMsgs;	/* discard messages that originated from ourselves */
 	sbool bUseSysTimeStamp;	/* use timestamp from system (instead of from message) */
 	sbool bUnlink;		/* unlink&re-create socket at start and end of processing */
+	sbool bUseSpecialParser;/* use "canned" log socket parser instead of parser chain? */
 } lstn_t;
 static lstn_t *listeners;
 
@@ -204,6 +206,8 @@ struct instanceConf_s {
 	int bParseTrusted;		/* parse trusted properties */
 	sbool bDiscardOwnMsgs;		/* discard messages that originated from our own pid? */
 	sbool bUnlink;
+	sbool bUseSpecialParser;
+	sbool bParseHost;
 	struct instanceConf_s *next;
 };
 
@@ -216,6 +220,8 @@ struct modConfData_s {
 	int ratelimitSeveritySysSock;
 	int bAnnotateSysSock;
 	int bParseTrusted;
+	int bUseSpecialParser;
+	int bParseHost;
 	sbool bIgnoreTimestamp;		/* ignore timestamps present in the incoming message? */
 	sbool bUseFlowCtl;		/* use flow control or not (if yes, only LIGHT is used! */
 	sbool bOmitLocalLogging;
@@ -239,6 +245,8 @@ static struct cnfparamdescr modpdescr[] = {
 	{ "syssock.usesystimestamp", eCmdHdlrBinary, 0 },
 	{ "syssock.annotate", eCmdHdlrBinary, 0 },
 	{ "syssock.parsetrusted", eCmdHdlrBinary, 0 },
+	{ "syssock.usespecialparser", eCmdHdlrBinary, 0 },
+	{ "syssock.parsehostname", eCmdHdlrBinary, 0 },
 	{ "syssock.usepidfromsystem", eCmdHdlrBinary, 0 },
 	{ "syssock.ratelimit.interval", eCmdHdlrInt, 0 },
 	{ "syssock.ratelimit.burst", eCmdHdlrInt, 0 },
@@ -262,6 +270,8 @@ static struct cnfparamdescr inppdescr[] = {
 	{ "flowcontrol", eCmdHdlrBinary, 0 },
 	{ "usesystimestamp", eCmdHdlrBinary, 0 },
 	{ "annotate", eCmdHdlrBinary, 0 },
+	{ "usespecialparser", eCmdHdlrBinary, 0 },
+	{ "parsehostname", eCmdHdlrBinary, 0 },
 	{ "usepidfromsystem", eCmdHdlrBinary, 0 },
 	{ "ratelimit.interval", eCmdHdlrInt, 0 },
 	{ "ratelimit.burst", eCmdHdlrInt, 0 },
@@ -294,6 +304,8 @@ createInstance(instanceConf_t **pinst)
 	inst->ratelimitBurst = DFLT_ratelimitBurst;
 	inst->ratelimitSeverity = DFLT_ratelimitSeverity;
 	inst->bUseFlowCtl = 0;
+	inst->bUseSpecialParser = 1;
+	inst->bParseHost = UNSET;
 	inst->bIgnoreTimestamp = 1;
 	inst->bCreatePath = DFLT_bCreatePath;
 	inst->bUseSysTimeStamp = 1;
@@ -349,10 +361,10 @@ static rsRetVal addInstance(void __attribute__((unused)) *pVal, uchar *pNewVal)
 	inst->bWritePid = cs.bWritePid;
 	inst->bAnnotate = cs.bAnnotate;
 	inst->bParseTrusted = cs.bParseTrusted;
+	inst->bParseHost = UNSET;
 	inst->next = NULL;
 
-	/* some legacy conf processing */
-	free(cs.pLogHostName); /* reset hostname for next socket */
+	/* reset hostname for next socket */
 	cs.pLogHostName = NULL;
 
 finalize_it:
@@ -368,10 +380,14 @@ addListner(instanceConf_t *inst)
 {
 	DEFiRet;
 
-	if(*inst->sockName == ':') {
-		listeners[nfd].bParseHost = 1;
+	if(inst->bParseHost == UNSET) {
+		if(*inst->sockName == ':') {
+			listeners[nfd].bParseHost = 1;
+		} else {
+			listeners[nfd].bParseHost = 0;
+		}
 	} else {
-		listeners[nfd].bParseHost = 0;
+		listeners[nfd].bParseHost = inst->bParseHost;
 	}
 	if(inst->pLogHostName == NULL) {
 		listeners[nfd].hostName = NULL;
@@ -405,6 +421,7 @@ addListner(instanceConf_t *inst)
 	listeners[nfd].bUnlink = inst->bUnlink;
 	listeners[nfd].bWritePid = inst->bWritePid;
 	listeners[nfd].bUseSysTimeStamp = inst->bUseSysTimeStamp;
+	listeners[nfd].bUseSpecialParser = inst->bUseSpecialParser;
 	CHKiRet(ratelimitNew(&listeners[nfd].dflt_ratelimiter, "imuxsock", NULL));
 	ratelimitSetLinuxLike(listeners[nfd].dflt_ratelimiter,
 			      listeners[nfd].ratelimitInterval,
@@ -774,9 +791,9 @@ SubmitMsg(uchar *pRcv, int lenRcv, lstn_t *pLstn, struct ucred *cred, struct tim
 	findRatelimiter(pLstn, cred, &ratelimiter); /* ignore error, better so than others... */
 
 	if(ts == NULL) {
-		datetime.getCurrTime(&st, &tt);
+		datetime.getCurrTime(&st, &tt, TIME_IN_LOCALTIME);
 	} else {
-		datetime.timeval2syslogTime(ts, &st);
+		datetime.timeval2syslogTime(ts, &st, TIME_IN_LOCALTIME);
 		tt = ts->tv_sec;
 	}
 
@@ -829,7 +846,7 @@ SubmitMsg(uchar *pRcv, int lenRcv, lstn_t *pLstn, struct ucred *cred, struct tim
 			/* as per lumberjack spec, these properties need to go into
 			 * the CEE root.
 			 */
-			msgAddJSON(pMsg, (uchar*)"!", json, 0);
+			msgAddJSON(pMsg, (uchar*)"!", json, 0, 0);
 
 			MsgSetRawMsg(pMsg, (char*)pRcv, lenRcv);
 		} else {
@@ -871,67 +888,78 @@ SubmitMsg(uchar *pRcv, int lenRcv, lstn_t *pLstn, struct ucred *cred, struct tim
 			pmsgbuf[toffs+1] = '\0';
 
 			MsgSetRawMsg(pMsg, (char*)pmsgbuf, toffs + 1);
+			if (pmsgbuf != msgbuf) {
+				free(pmsgbuf);
+			}
 		}
 	} else {
 		/* just add the unmodified message */
 		MsgSetRawMsg(pMsg, (char*)pRcv, lenRcv);
 	}
 
-	parser.SanitizeMsg(pMsg);
-	lenMsg = pMsg->iLenRawMsg - offs; /* SanitizeMsg() may have changed the size */
-	MsgSetInputName(pMsg, pInputName);
 	MsgSetFlowControlType(pMsg, pLstn->flowCtl);
-	msgSetPRI(pMsg, pri);
-	MsgSetAfterPRIOffs(pMsg, offs);
-
-	parse++; lenMsg--; /* '>' */
-
-	if(ts == NULL) {
-		if((pLstn->flags & IGNDATE)) {
-			/* in this case, we still need to find out if we have a valid
-			 * datestamp or not .. and advance the parse pointer accordingly.
-			 */
-			if (datetime.ParseTIMESTAMP3339(&dummyTS, &parse, &lenMsg) != RS_RET_OK) {
-  				datetime.ParseTIMESTAMP3164(&dummyTS, &parse, &lenMsg, NO_PARSE3164_TZSTRING);
-			}
-		} else {
-			if(datetime.ParseTIMESTAMP3339(&(pMsg->tTIMESTAMP), &parse, &lenMsg) != RS_RET_OK &&
-			   datetime.ParseTIMESTAMP3164(&(pMsg->tTIMESTAMP), &parse, &lenMsg, NO_PARSE3164_TZSTRING) != RS_RET_OK) {
-				DBGPRINTF("we have a problem, invalid timestamp in msg!\n");
-			}
-		}
-	} else { /* if we pulled the time from the system, we need to update the message text */
-		uchar *tmpParse = parse; /* just to check correctness of TS */
-		if(datetime.ParseTIMESTAMP3339(&dummyTS, &tmpParse, &lenMsg) == RS_RET_OK ||
-		   datetime.ParseTIMESTAMP3164(&dummyTS, &tmpParse, &lenMsg, NO_PARSE3164_TZSTRING) == RS_RET_OK) {
-			/* We modify the message only if it contained a valid timestamp,
-			 * otherwise we do not touch it at all. */
-			datetime.formatTimestamp3164(&st, (char*)parse, 0);
-			parse[15] = ' '; /* re-write \0 from fromatTimestamp3164 by SP */
-			/* update "counters" to reflect processed timestamp */
-			parse += 16;
-		}
-	}
-
-	/* pull tag */
-
-	i = 0;
-	while(lenMsg > 0 && *parse != ' ' && i < CONF_TAG_MAXSIZE - 1) {
-		bufParseTAG[i++] = *parse++;
-		--lenMsg;
-	}
-	bufParseTAG[i] = '\0';	/* terminate string */
-	if(pLstn->bWritePid)
-		fixPID(bufParseTAG, &i, cred);
-	MsgSetTAG(pMsg, bufParseTAG, i);
-	MsgSetMSGoffs(pMsg, pMsg->iLenRawMsg - lenMsg);
-
+	MsgSetInputName(pMsg, pInputName);
 	if(pLstn->bParseHost) {
 		pMsg->msgFlags  = pLstn->flags | PARSE_HOSTNAME;
 	} else {
 		pMsg->msgFlags  = pLstn->flags;
 	}
 
+	if(pLstn->bUseSpecialParser) {
+		/* this is the legacy "log socket" parser which was written on the assumption
+		 * that the log socket format would be fixed. While many folks said so, it
+		 * seems to be different in practice, and this is why we now have choices...
+		 * rgerhards, 2015-03-03
+		 */
+		parser.SanitizeMsg(pMsg);
+		lenMsg = pMsg->iLenRawMsg - offs; /* SanitizeMsg() may have changed the size */
+		msgSetPRI(pMsg, pri);
+		MsgSetAfterPRIOffs(pMsg, offs);
+
+		parse++; lenMsg--; /* '>' */
+		if(ts == NULL) {
+			if((pLstn->flags & IGNDATE)) {
+				/* in this case, we still need to find out if we have a valid
+				 * datestamp or not .. and advance the parse pointer accordingly.
+				 */
+				if (datetime.ParseTIMESTAMP3339(&dummyTS, &parse, &lenMsg) != RS_RET_OK) {
+					datetime.ParseTIMESTAMP3164(&dummyTS, &parse, &lenMsg, NO_PARSE3164_TZSTRING, NO_PERMIT_YEAR_AFTER_TIME);
+				}
+			} else {
+				if(datetime.ParseTIMESTAMP3339(&(pMsg->tTIMESTAMP), &parse, &lenMsg) != RS_RET_OK &&
+				   datetime.ParseTIMESTAMP3164(&(pMsg->tTIMESTAMP), &parse, &lenMsg, NO_PARSE3164_TZSTRING, NO_PERMIT_YEAR_AFTER_TIME) != RS_RET_OK) {
+					DBGPRINTF("we have a problem, invalid timestamp in msg!\n");
+				}
+			}
+		} else { /* if we pulled the time from the system, we need to update the message text */
+			uchar *tmpParse = parse; /* just to check correctness of TS */
+			if(datetime.ParseTIMESTAMP3339(&dummyTS, &tmpParse, &lenMsg) == RS_RET_OK ||
+			   datetime.ParseTIMESTAMP3164(&dummyTS, &tmpParse, &lenMsg, NO_PARSE3164_TZSTRING, NO_PERMIT_YEAR_AFTER_TIME) == RS_RET_OK) {
+				/* We modify the message only if it contained a valid timestamp,
+				 * otherwise we do not touch it at all. */
+				datetime.formatTimestamp3164(&st, (char*)parse, 0);
+				parse[15] = ' '; /* re-write \0 from fromatTimestamp3164 by SP */
+				/* update "counters" to reflect processed timestamp */
+				parse += 16;
+			}
+		}
+
+		/* pull tag */
+
+		i = 0;
+		while(lenMsg > 0 && *parse != ' ' && i < CONF_TAG_MAXSIZE - 1) {
+			bufParseTAG[i++] = *parse++;
+			--lenMsg;
+		}
+		bufParseTAG[i] = '\0';	/* terminate string */
+		if(pLstn->bWritePid)
+			fixPID(bufParseTAG, &i, cred);
+		MsgSetTAG(pMsg, bufParseTAG, i);
+		MsgSetMSGoffs(pMsg, pMsg->iLenRawMsg - lenMsg);
+	} else { /* we are configured to use regular parser chain */
+		pMsg->msgFlags  |= NEEDS_PARSING;
+	}
+
 	MsgSetRcvFrom(pMsg, pLstn->hostName == NULL ? glbl.GetLocalHostNameProp() : pLstn->hostName);
 	CHKiRet(MsgSetRcvFromIP(pMsg, pLocalHostIP));
 	ratelimitAddMsg(ratelimiter, NULL, pMsg);
@@ -980,7 +1008,7 @@ static rsRetVal readSocket(lstn_t *pLstn)
 	if((size_t) iMaxLine < sizeof(bufRcv) - 1) {
 		pRcv = bufRcv;
 	} else {
-		CHKmalloc(pRcv = (uchar*) MALLOC(sizeof(uchar) * (iMaxLine + 1)));
+		CHKmalloc(pRcv = (uchar*) MALLOC(iMaxLine + 1));
 	}
 
 	memset(&msgh, 0, sizeof(msgh));
@@ -1078,6 +1106,8 @@ activateListeners()
 		listeners[0].bWritePid = runModConf->bWritePidSysSock;
 		listeners[0].bAnnotate = runModConf->bAnnotateSysSock;
 		listeners[0].bParseTrusted = runModConf->bParseTrusted;
+		listeners[0].bParseHost = runModConf->bParseHost;
+		listeners[0].bUseSpecialParser = runModConf->bUseSpecialParser;
 		listeners[0].bDiscardOwnMsgs = runModConf->bDiscardOwnMsgs;
 		listeners[0].bUnlink = runModConf->bUnlink;
 		listeners[0].bUseSysTimeStamp = runModConf->bUseSysTimeStamp;
@@ -1130,6 +1160,8 @@ CODESTARTbeginCnfLoad
 	pModConf->bWritePidSysSock = 0;
 	pModConf->bAnnotateSysSock = 0;
 	pModConf->bParseTrusted = 0;
+	pModConf->bParseHost = UNSET;
+	pModConf->bUseSpecialParser = 1;
 	pModConf->bDiscardOwnMsgs = 1;
 	pModConf->bUnlink = 1;
 	pModConf->ratelimitIntervalSysSock = DFLT_ratelimitInterval;
@@ -1178,6 +1210,10 @@ CODESTARTsetModCnf
 			loadModConf->bAnnotateSysSock = (int) pvals[i].val.d.n;
 		} else if(!strcmp(modpblk.descr[i].name, "syssock.parsetrusted")) {
 			loadModConf->bParseTrusted = (int) pvals[i].val.d.n;
+		} else if(!strcmp(modpblk.descr[i].name, "syssock.parsehostname")) {
+			loadModConf->bParseHost = (int) pvals[i].val.d.n;
+		} else if(!strcmp(modpblk.descr[i].name, "syssock.usespecialparser")) {
+			loadModConf->bUseSpecialParser = (int) pvals[i].val.d.n;
 		} else if(!strcmp(modpblk.descr[i].name, "syssock.usepidfromsystem")) {
 			loadModConf->bWritePidSysSock = (int) pvals[i].val.d.n;
 		} else if(!strcmp(modpblk.descr[i].name, "syssock.ratelimit.interval")) {
@@ -1248,6 +1284,10 @@ CODESTARTnewInpInst
 			inst->bAnnotate = (int) pvals[i].val.d.n;
 		} else if(!strcmp(inppblk.descr[i].name, "usepidfromsystem")) {
 			inst->bWritePid = (int) pvals[i].val.d.n;
+		} else if(!strcmp(inppblk.descr[i].name, "parsehostname")) {
+			inst->bParseHost  = (int) pvals[i].val.d.n;
+		} else if(!strcmp(inppblk.descr[i].name, "usespecialparser")) {
+			inst->bUseSpecialParser  = (int) pvals[i].val.d.n;
 		} else if(!strcmp(inppblk.descr[i].name, "ratelimit.interval")) {
 			inst->ratelimitInterval = (int) pvals[i].val.d.n;
 		} else if(!strcmp(inppblk.descr[i].name, "ratelimit.burst")) {
