@@ -52,6 +52,7 @@ DEFobjCurrIf(errmsg)
 DEFobjCurrIf(statsobj)
 
 statsobj_t *kafkaStats;
+int ctrQueueSize;
 STATSCOUNTER_DEF(ctrTopicSubmit, mutCtrTopicSubmit);
 STATSCOUNTER_DEF(ctrKafkaFail, mutCtrKafkaFail);
 STATSCOUNTER_DEF(ctrCacheMiss, mutCtrCacheMiss);
@@ -113,7 +114,7 @@ typedef struct _instanceData {
 	sbool autoPartition;
 	int fixedPartition;
 	int nPartitions;
-	int32_t currPartition;
+	uint32_t currPartition;
 	int nConfParams;
 	struct kafka_params *confParams;
 	int nTopicConfParams;
@@ -160,16 +161,16 @@ BEGINinitConfVars		/* (re)set config variables to default values */
 CODESTARTinitConfVars 
 ENDinitConfVars
 
-static inline int
+static inline uint32_t
 getPartition(instanceData *const __restrict__ pData)
 {
 	if (pData->autoPartition) {
 		return RD_KAFKA_PARTITION_UA;
 	} else {
 		return (pData->fixedPartition == NO_FIXED_PARTITION) ?
-		          ATOMIC_INC_AND_FETCH_int(&pData->currPartition,
+		          ATOMIC_INC_AND_FETCH_unsigned(&pData->currPartition,
 			      &pData->mutCurrPartition) % pData->nPartitions
-			:  pData->fixedPartition;
+			:  (unsigned) pData->fixedPartition;
 	}
 }
 
@@ -788,6 +789,7 @@ writeKafka(instanceData *pData, uchar *msg, uchar *topic)
 	const int partition = getPartition(pData);
 	rd_kafka_topic_t *rkt = NULL;
 	pthread_rwlock_t *dynTopicLock = NULL;
+	int msg_enqueue_status = 0;
 
 	DBGPRINTF("omkafka: trying to send: key:'%s', msg:'%s'\n", pData->key, msg);
 
@@ -797,31 +799,39 @@ writeKafka(instanceData *pData, uchar *msg, uchar *topic)
 	} else {
 		rkt = pData->pTopic;
 	}
-	if(rd_kafka_produce(rkt, partition, RD_KAFKA_MSG_F_COPY,
-	                    msg, strlen((char*)msg), pData->key,
-	                    pData->key == NULL ? 0 : strlen((char*)pData->key),
-	                    NULL) == -1) {
+
+	msg_enqueue_status = rd_kafka_produce(rkt, partition, RD_KAFKA_MSG_F_COPY,
+										  msg, strlen((char*)msg), pData->key,
+										  pData->key == NULL ? 0 : strlen((char*)pData->key),
+										  NULL);
+	if(msg_enqueue_status == -1) {
 		errmsg.LogError(0, RS_RET_KAFKA_PRODUCE_ERR,
 			"omkafka: Failed to produce to topic '%s' "
 			"partition %d: %s\n",
 			rd_kafka_topic_name(rkt), partition,
 			rd_kafka_err2str(rd_kafka_errno2err(errno)));
-		STATSCOUNTER_INC(ctrKafkaFail, mutCtrKafkaFail);
-		ABORT_FINALIZE(RS_RET_KAFKA_PRODUCE_ERR);
 	}
 	const int callbacksCalled = rd_kafka_poll(pData->rk, 0); /* call callbacks */
 	if (pData->dynaTopic) {
 		pthread_rwlock_unlock(dynTopicLock);/* dynamic topic can't be used beyond this pt */
 	}
-
 	DBGPRINTF("omkafka: kafka outqueue length: %d, callbacks called %d\n",
-		  rd_kafka_outq_len(pData->rk), callbacksCalled);
+			  rd_kafka_outq_len(pData->rk), callbacksCalled);
+
+	if (msg_enqueue_status == -1) {
+		STATSCOUNTER_INC(ctrKafkaFail, mutCtrKafkaFail);
+		ABORT_FINALIZE(RS_RET_KAFKA_PRODUCE_ERR);
+		/* ABORT_FINALIZE isn't absolutely necessary as of now,
+		   because this is the last line anyway, but its useful to ensure
+		   correctness in case we add more stuff below this line at some point*/
+	}
 
 finalize_it:
 	DBGPRINTF("omkafka: writeKafka returned %d\n", iRet);
 	if(iRet != RS_RET_OK) {
 		iRet = RS_RET_SUSPENDED;
 	}
+    STATSCOUNTER_SETMAX_NOMUT(ctrQueueSize, rd_kafka_outq_len(pData->rk));
 	STATSCOUNTER_INC(ctrTopicSubmit, mutCtrTopicSubmit);
 	RETiRet;
 }
@@ -917,8 +927,6 @@ CODESTARTnewActInst
 		} else if(!strcmp(actpblk.descr[i].name, "broker")) {
 			es_str_t *es = es_newStr(128);
 			int bNeedComma = 0;
-			CHKmalloc(pData->brokers = malloc(sizeof(char*) *
-			                                  pvals[i].val.d.ar->nmemb ));
 			for(int j = 0 ; j <  pvals[i].val.d.ar->nmemb ; ++j) {
 				if(bNeedComma)
 					es_addChar(&es, ',');
@@ -932,18 +940,22 @@ CODESTARTnewActInst
 			CHKmalloc(pData->confParams = malloc(sizeof(struct kafka_params) *
 			                                      pvals[i].val.d.ar->nmemb ));
 			for(int j = 0 ; j <  pvals[i].val.d.ar->nmemb ; ++j) {
-				CHKiRet(processKafkaParam(es_str2cstr(pvals[i].val.d.ar->arr[j], NULL),
+				char *cstr = es_str2cstr(pvals[i].val.d.ar->arr[j], NULL);
+				CHKiRet(processKafkaParam(cstr,
 							&pData->confParams[j].name,
 							&pData->confParams[j].val));
+				free(cstr);
 			}
 		} else if(!strcmp(actpblk.descr[i].name, "topicconfparam")) {
 			pData->nTopicConfParams = pvals[i].val.d.ar->nmemb;
 			CHKmalloc(pData->topicConfParams = malloc(sizeof(struct kafka_params) *
 			                                      pvals[i].val.d.ar->nmemb ));
 			for(int j = 0 ; j <  pvals[i].val.d.ar->nmemb ; ++j) {
-				CHKiRet(processKafkaParam(es_str2cstr(pvals[i].val.d.ar->arr[j], NULL),
+				char *cstr = es_str2cstr(pvals[i].val.d.ar->arr[j], NULL);
+				CHKiRet(processKafkaParam(cstr,
 							&pData->topicConfParams[j].name,
 							&pData->topicConfParams[j].val));
+				free(cstr);
 			}
 		} else if(!strcmp(actpblk.descr[i].name, "errorfile")) {
 			pData->errorFile = (uchar*)es_str2cstr(pvals[i].val.d.estr, NULL);
@@ -1049,6 +1061,9 @@ CODEmodInit_QueryRegCFSLineHdlr
 	STATSCOUNTER_INIT(ctrTopicSubmit, mutCtrTopicSubmit);
 	CHKiRet(statsobj.AddCounter(kafkaStats, (uchar *)"submitted",
 		ctrType_IntCtr, CTR_FLAG_RESETTABLE, &ctrTopicSubmit));
+    ctrQueueSize = 0;
+    CHKiRet(statsobj.AddCounter(kafkaStats, (uchar *)"maxoutqsize",
+        ctrType_Int, CTR_FLAG_NONE, &ctrQueueSize));
 	STATSCOUNTER_INIT(ctrKafkaFail, mutCtrKafkaFail);
 	CHKiRet(statsobj.AddCounter(kafkaStats, (uchar *)"failures",
 		ctrType_IntCtr, CTR_FLAG_RESETTABLE, &ctrKafkaFail));
