@@ -6,7 +6,7 @@
  *
  * File begun on 2007-07-20 by RGerhards (extracted from syslogd.c)
  *
- * Copyright 2007-2013 Adiscon GmbH.
+ * Copyright 2007-2014 Adiscon GmbH.
  *
  * This file is part of rsyslog.
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -38,7 +38,6 @@
 #include "syslogd-types.h"
 #include "srUtils.h"
 #include "template.h"
-#include "ommysql.h"
 #include "module-template.h"
 #include "errmsg.h"
 #include "cfsysline.h"
@@ -144,6 +143,7 @@ ENDfreeInstance
 BEGINfreeWrkrInstance
 CODESTARTfreeWrkrInstance
 	closeMySQL(pWrkrData);
+	mysql_thread_end();
 ENDfreeWrkrInstance
 
 
@@ -168,7 +168,7 @@ static void reportDBError(wrkrInstanceData_t *pWrkrData, int bSilent)
 		errmsg.LogError(0, NO_ERRCODE, "unknown DB error occured - could not obtain MySQL handle");
 	} else { /* we can ask mysql for the error description... */
 		uMySQLErrno = mysql_errno(pWrkrData->hmysql);
-		snprintf(errMsg, sizeof(errMsg)/sizeof(char), "db error (%d): %s\n", uMySQLErrno,
+		snprintf(errMsg, sizeof(errMsg), "db error (%d): %s\n", uMySQLErrno,
 			mysql_error(pWrkrData->hmysql));
 		if(bSilent || uMySQLErrno == pWrkrData->uLastMySQLErrno)
 			dbgprintf("mysql, DBError(silent): %s\n", errMsg);
@@ -205,7 +205,7 @@ static rsRetVal initMySQL(wrkrInstanceData_t *pWrkrData, int bSilent)
 			int err=errno;
 			if(fp==NULL){
 				char msg[512];
-				snprintf(msg,sizeof(msg)/sizeof(char),"Could not open '%s' for reading",pData->configfile);
+				snprintf(msg,sizeof(msg),"Could not open '%s' for reading",pData->configfile);
 				if(bSilent) {
 					char errStr[512];
 					rs_strerror_r(err, errStr, sizeof(errStr));
@@ -366,7 +366,6 @@ CODESTARTnewActInst
 			OMSR_RQD_TPL_OPT_SQL));
 	}
 CODE_STD_FINALIZERnewActInst
-dbgprintf("XXXX: added param, iRet %d\n", iRet);
 	cnfparamvalsDestruct(pvals, &actpblk);
 ENDnewActInst
 
