@@ -139,7 +139,7 @@ CODESTARTfreeInstance
 		for (i = 0; i < pData->iParams; i++) {
 			free(pData->aParams[i]);
 		}
-		free(pData->aParams); 
+		free(pData->aParams);
 	}
 ENDfreeInstance
 
@@ -170,7 +170,6 @@ writeProgramOutput(wrkrInstanceData_t *__restrict__ const pWrkrData,
 	char errStr[1024];
 	ssize_t r;
 
-dbgprintf("omprog: writeProgramOutput, fd %d\n", pWrkrData->fdOutput);
 	if(pWrkrData->fdOutput == -1) {
 		pWrkrData->fdOutput = open((char*)pWrkrData->pData->outputFileName,
 				       O_WRONLY | O_APPEND | O_CREAT, 0600);
@@ -282,10 +281,10 @@ execBinary(wrkrInstanceData_t *pWrkrData, int fdStdin, int fdStdOutErr)
 		 */
 		rs_strerror_r(errno, errStr, sizeof(errStr));
 		DBGPRINTF("omprog: failed to execute binary '%s': %s\n",
-			  pWrkrData->pData->szBinary, errStr); 
+			  pWrkrData->pData->szBinary, errStr);
 		openlog("rsyslogd", 0, LOG_SYSLOG);
 		syslog(LOG_ERR, "omprog: failed to execute binary '%s': %s\n",
-			  pWrkrData->pData->szBinary, errStr); 
+			  pWrkrData->pData->szBinary, errStr);
 	}
 	
 	/* we should never reach this point, but if we do, we terminate */
@@ -512,8 +511,8 @@ CODESTARTnewActInst
 		if(!pvals[i].bUsed)
 			continue;
 		if(!strcmp(actpblk.descr[i].name, "binary")) {
-			estrBinary = pvals[i].val.d.estr; 
-			estrParams = NULL; 
+			estrBinary = pvals[i].val.d.estr;
+			estrParams = NULL;
 
 			/* Search for space */
 			c = es_getBufAddr(pvals[i].val.d.estr);
@@ -521,18 +520,22 @@ CODESTARTnewActInst
 			while(iCnt < es_strlen(pvals[i].val.d.estr) ) {
 				if (c[iCnt] == ' ') {
 					/* Split binary name from parameters */
-					estrBinary = es_newStrFromSubStr ( pvals[i].val.d.estr, 0, iCnt ); 
-					estrParams = es_newStrFromSubStr ( pvals[i].val.d.estr, iCnt+1, es_strlen(pvals[i].val.d.estr)); 
+					estrBinary = es_newStrFromSubStr ( pvals[i].val.d.estr, 0, iCnt );
+					estrParams = es_newStrFromSubStr ( pvals[i].val.d.estr, iCnt+1, es_strlen(pvals[i].val.d.estr));
 					break;
 				}
 				iCnt++;
 			}	
 			/* Assign binary and params */
 			pData->szBinary = (uchar*)es_str2cstr(estrBinary, NULL);
-			dbgprintf("omprog: szBinary = '%s'\n", pData->szBinary); 
+			DBGPRINTF("omprog: szBinary = '%s'\n", pData->szBinary);
 			/* Check for Params! */
 			if (estrParams != NULL) {
-				dbgprintf("omprog: szParams = '%s'\n", es_str2cstr(estrParams, NULL) ); 
+				if(Debug) {
+					char *params = es_str2cstr(estrParams, NULL);
+					dbgprintf("omprog: szParams = '%s'\n", params);
+					free(params);
+				}
 				
 				/* Count parameters if set */
 				c = es_getBufAddr(estrParams); /* Reset to beginning */
@@ -540,10 +543,10 @@ CODESTARTnewActInst
 				iCnt = 0;
 				while(iCnt < es_strlen(estrParams) ) {
 					if (c[iCnt] == ' ' && c[iCnt-1] != '\\')
-						 pData->iParams++; 
+						 pData->iParams++;
 					iCnt++;
 				}
-				dbgprintf("omprog: iParams = '%d'\n", pData->iParams); 
+				DBGPRINTF("omprog: iParams = '%d'\n", pData->iParams);
 
 				/* Create argv Array */
 				CHKmalloc(pData->aParams = malloc( (pData->iParams+1) * sizeof(char*))); /* One more for first param */ 
@@ -551,32 +554,32 @@ CODESTARTnewActInst
 				/* Second Loop, create parameter array*/
 				c = es_getBufAddr(estrParams); /* Reset to beginning */
 				iCnt = iStr = iPrm = 0;
-				estrTmp = NULL; 
-				bInQuotes = FALSE; 
+				estrTmp = NULL;
+				bInQuotes = FALSE;
 				/* Set first parameter to binary */
-				pData->aParams[iPrm] = strdup((char*)pData->szBinary); 
-				dbgprintf("omprog: Param (%d): '%s'\n", iPrm, pData->aParams[iPrm]);
-				iPrm++; 
+				pData->aParams[iPrm] = strdup((char*)pData->szBinary);
+				DBGPRINTF("omprog: Param (%d): '%s'\n", iPrm, pData->aParams[iPrm]);
+				iPrm++;
 				while(iCnt < es_strlen(estrParams) ) {
 					if ( c[iCnt] == ' ' && !bInQuotes ) {
 						/* Copy into Param Array! */
-						estrTmp = es_newStrFromSubStr( estrParams, iStr, iCnt-iStr); 
+						estrTmp = es_newStrFromSubStr( estrParams, iStr, iCnt-iStr);
 					}
 					else if ( iCnt+1 >= es_strlen(estrParams) ) {
 						/* Copy rest of string into Param Array! */
-						estrTmp = es_newStrFromSubStr( estrParams, iStr, iCnt-iStr+1); 
+						estrTmp = es_newStrFromSubStr( estrParams, iStr, iCnt-iStr+1);
 					}
 					else if (c[iCnt] == '"') {
 						/* switch inQuotes Mode */
-						bInQuotes = !bInQuotes; 
+						bInQuotes = !bInQuotes;
 					}
 
 					if ( estrTmp != NULL ) {
-						pData->aParams[iPrm] = es_str2cstr(estrTmp, NULL); 
+						pData->aParams[iPrm] = es_str2cstr(estrTmp, NULL);
 						iStr = iCnt+1; /* Set new start */
-						dbgprintf("omprog: Param (%d): '%s'\n", iPrm, pData->aParams[iPrm]);
+						DBGPRINTF("omprog: Param (%d): '%s'\n", iPrm, pData->aParams[iPrm]);
 						es_deleteStr( estrTmp );
-						estrTmp = NULL; 
+						estrTmp = NULL;
 						iPrm++;
 					}
 
@@ -584,7 +587,7 @@ CODESTARTnewActInst
 					iCnt++;
 				}
 				/* NULL last parameter! */
-				pData->aParams[iPrm] = NULL; 
+				pData->aParams[iPrm] = NULL;
 
 			}
 		} else if(!strcmp(actpblk.descr[i].name, "output")) {
@@ -592,28 +595,27 @@ CODESTARTnewActInst
 		} else if(!strcmp(actpblk.descr[i].name, "forcesingleinstance")) {
 			pData->bForceSingleInst = (int) pvals[i].val.d.n;
 		} else if(!strcmp(actpblk.descr[i].name, "hup.signal")) {
-			const char *const signal = es_str2cstr(pvals[i].val.d.estr, NULL);
-			if(!strcmp(signal, "HUP"))
+			const char *const sig = es_str2cstr(pvals[i].val.d.estr, NULL);
+			if(!strcmp(sig, "HUP"))
 				pData->iHUPForward = SIGHUP;
-			else if(!strcmp(signal, "USR1"))
+			else if(!strcmp(sig, "USR1"))
 				pData->iHUPForward = SIGUSR1;
-			else if(!strcmp(signal, "USR2"))
+			else if(!strcmp(sig, "USR2"))
 				pData->iHUPForward = SIGUSR2;
-			else if(!strcmp(signal, "INT"))
+			else if(!strcmp(sig, "INT"))
 				pData->iHUPForward = SIGINT;
-			else if(!strcmp(signal, "TERM"))
+			else if(!strcmp(sig, "TERM"))
 				pData->iHUPForward = SIGTERM;
 			else {
 				errmsg.LogError(0, RS_RET_CONF_PARAM_INVLD,
-					"omprog: hup.signal '%s' in hup.signal parameter",
-					signal);
+					"omprog: hup.signal '%s' in hup.signal parameter", sig);
 				ABORT_FINALIZE(RS_RET_CONF_PARAM_INVLD);
 			}
-			free((void*)signal);
+			free((void*)sig);
 		} else if(!strcmp(actpblk.descr[i].name, "template")) {
 			pData->tplName = (uchar*)es_str2cstr(pvals[i].val.d.estr, NULL);
 		} else {
-			dbgprintf("omprog: program error, non-handled param '%s'\n", actpblk.descr[i].name);
+			DBGPRINTF("omprog: program error, non-handled param '%s'\n", actpblk.descr[i].name);
 		}
 	}
 
