@@ -181,18 +181,18 @@
 		(*data) -= val;
 		pthread_mutex_unlock(phlpmut);
 	}
-#	define DEF_ATOMIC_HELPER_MUT(x)  pthread_mutex_t x
-#	define INIT_ATOMIC_HELPER_MUT(x) pthread_mutex_init(&(x), NULL)
-#	define DESTROY_ATOMIC_HELPER_MUT(x) pthread_mutex_destroy(&(x))
+#	define DEF_ATOMIC_HELPER_MUT(x)  pthread_mutex_t x;
+#	define INIT_ATOMIC_HELPER_MUT(x) pthread_mutex_init(&(x), NULL);
+#	define DESTROY_ATOMIC_HELPER_MUT(x) pthread_mutex_destroy(&(x));
 
 #	define PREFER_ATOMIC_INC(data) ((void) ++data)
 
 #endif
 
 /* we need to handle 64bit atomics seperately as some platforms have 
- * 32 bit atomics, but not 64 biot ones... -- rgerhards, 2010-12-01
+ * 32 bit atomics, but not 64 bit ones... -- rgerhards, 2010-12-01
  */
-#ifdef HAVE_ATOMIC_BUILTINS_64BIT
+#ifdef HAVE_ATOMIC_BUILTINS64
 #	define ATOMIC_INC_uint64(data, phlpmut) ((void) __sync_fetch_and_add(data, 1))
 #	define ATOMIC_DEC_unit64(data, phlpmut) ((void) __sync_sub_and_fetch(data, 1))
 #	define ATOMIC_INC_AND_FETCH_uint64(data, phlpmut) __sync_fetch_and_add(data, 1)
@@ -221,9 +221,9 @@
 		return(val);
 	}
 
-#	define DEF_ATOMIC_HELPER_MUT64(x)  pthread_mutex_t x
+#	define DEF_ATOMIC_HELPER_MUT64(x)  pthread_mutex_t x;
 #	define INIT_ATOMIC_HELPER_MUT64(x) pthread_mutex_init(&(x), NULL)
 #	define DESTROY_ATOMIC_HELPER_MUT64(x) pthread_mutex_destroy(&(x))
-#endif /* #ifdef HAVE_ATOMIC_BUILTINS_64BIT */
+#endif /* #ifdef HAVE_ATOMIC_BUILTINS64 */
 
 #endif /* #ifndef INCLUDED_ATOMIC_H */
