@@ -17,7 +17,7 @@
  * information (most importantly last block hash) and sigblkConstruct
  * reads (or initilizes if not present) it.
  *
- * Copyright 2013 Adiscon GmbH.
+ * Copyright 2013-2016 Adiscon GmbH.
  *
  * This file is part of rsyslog.
  *
@@ -60,6 +60,8 @@ typedef unsigned char uchar;
 #define VERSION "no-version"
 #endif
 
+int RSGT_FLAG_TLV16_RUNTIME = RSGT_FLAG_TLV16;
+int RSGT_FLAG_NONCRIT_RUNTIME = RSGT_FLAG_NONCRIT; 
 
 static void
 reportErr(gtctx ctx, char *errmsg)
@@ -144,7 +146,7 @@ rsgtExit(void)
 static inline gtfile
 rsgtfileConstruct(gtctx ctx)
 {
-	gtfile gf;
+	gtfile gf = NULL;
 	if((gf = calloc(1, sizeof(struct gtfile_s))) == NULL)
 		goto done;
 	gf->ctx = ctx;
@@ -282,26 +284,26 @@ done:	return r;
 }
 
 
-int
+static int
 tlv8Write(gtfile gf, int flags, int tlvtype, int len)
 {
 	int r;
 	assert((flags & RSGT_TYPE_MASK) == 0);
 	assert((tlvtype & RSGT_TYPE_MASK) == tlvtype);
-	r = tlvbufAddOctet(gf, (flags & ~RSGT_FLAG_TLV16) | tlvtype);
+	r = tlvbufAddOctet(gf, (flags & ~RSGT_FLAG_TLV16_RUNTIME) | tlvtype);
 	if(r != 0) goto done;
 	r = tlvbufAddOctet(gf, len & 0xff);
 done:	return r;
 } 
 
-int
+static int
 tlv16Write(gtfile gf, int flags, int tlvtype, uint16_t len)
 {
 	uint16_t typ;
 	int r;
 	assert((flags & RSGT_TYPE_MASK) == 0);
 	assert((tlvtype >> 8 & RSGT_TYPE_MASK) == (tlvtype >> 8));
-	typ = ((flags | RSGT_FLAG_TLV16) << 8) | tlvtype;
+	typ = ((flags | RSGT_FLAG_TLV16_RUNTIME) << 8) | tlvtype;
 	r = tlvbufAddOctet(gf, typ >> 8);
 	if(r != 0) goto done;
 	r = tlvbufAddOctet(gf, typ & 0xff);
@@ -332,6 +334,29 @@ tlvWriteHash(gtfile gf, uint16_t tlvtype, GTDataHash *rec)
 done:	return r;
 }
 
+int
+tlvWriteBlockHdr(gtfile gf) {
+	unsigned tlvlen;
+	int r;
+	tlvlen  = 2 + 1 /* hash algo TLV */ +
+	 	  2 + hashOutputLengthOctets(gf->hashAlg) /* iv */ +
+		  2 + 1 + gf->x_prev->len /* last hash */;
+	/* write top-level TLV object block-hdr */
+	CHKr(tlv16Write(gf, 0x00, 0x0901, tlvlen));
+	/* and now write the children */
+	/* hash-algo */
+	CHKr(tlv8Write(gf, 0x00, 0x01, 1));
+	CHKr(tlvbufAddOctet(gf, hashIdentifier(gf->hashAlg)));
+	/* block-iv */
+	CHKr(tlv8Write(gf, 0x00, 0x02, hashOutputLengthOctets(gf->hashAlg)));
+	CHKr(tlvbufAddOctetString(gf, gf->IV, hashOutputLengthOctets(gf->hashAlg)));
+	/* last-hash */
+	CHKr(tlv8Write(gf, 0x00, 0x03, gf->x_prev->len + 1));
+	CHKr(tlvbufAddOctet(gf, gf->x_prev->hashID));
+	CHKr(tlvbufAddOctetString(gf, gf->x_prev->data, gf->x_prev->len));
+done:	return r;
+}
+
 int
 tlvWriteBlockSig(gtfile gf, uchar *der, uint16_t lenDer)
 {
@@ -340,35 +365,15 @@ tlvWriteBlockSig(gtfile gf, uchar *der, uint16_t lenDer)
 	int r;
 
 	tlvlenRecords = tlvbufGetInt64OctetSize(gf->nRecords);
-	tlvlen  = 2 + 1 /* hash algo TLV */ +
-	 	  2 + hashOutputLengthOctets(gf->hashAlg) /* iv */ +
-		  2 + 1 + gf->lenBlkStrtHash /* last hash */ +
-		  2 + tlvlenRecords /* rec-count */ +
+	tlvlen  = 2 + tlvlenRecords /* rec-count */ +
 		  4 + lenDer /* rfc-3161 */;
 	/* write top-level TLV object (block-sig */
-	r = tlv16Write(gf, 0x00, 0x0902, tlvlen);
+	r = tlv16Write(gf, 0x00, 0x0904, tlvlen);
 	if(r != 0) goto done;
 	/* and now write the children */
 	//FIXME: flags???
-	/* hash-algo */
-	r = tlv8Write(gf, 0x00, 0x00, 1);
-	if(r != 0) goto done;
-	r = tlvbufAddOctet(gf, hashIdentifier(gf->hashAlg));
-	if(r != 0) goto done;
-	/* block-iv */
-	r = tlv8Write(gf, 0x00, 0x01, hashOutputLengthOctets(gf->hashAlg));
-	if(r != 0) goto done;
-	r = tlvbufAddOctetString(gf, gf->IV, hashOutputLengthOctets(gf->hashAlg));
-	if(r != 0) goto done;
-	/* last-hash */
-	r = tlv8Write(gf, 0x00, 0x02, gf->lenBlkStrtHash+1);
-	if(r != 0) goto done;
-	r = tlvbufAddOctet(gf, hashIdentifier(gf->hashAlg));
-	if(r != 0) goto done;
-	r = tlvbufAddOctetString(gf, gf->blkStrtHash, gf->lenBlkStrtHash);
-	if(r != 0) goto done;
 	/* rec-count */
-	r = tlv8Write(gf, 0x00, 0x03, tlvlenRecords);
+	r = tlv8Write(gf, 0x00, 0x01, tlvlenRecords);
 	if(r != 0) goto done;
 	r = tlvbufAddInt64(gf, gf->nRecords);
 	if(r != 0) goto done;
@@ -400,19 +405,31 @@ readStateFile(gtfile gf)
 	if(read(fd, &sf, sizeof(sf)) != sizeof(sf)) goto err;
 	if(strncmp(sf.hdr, "GTSTAT10", 8)) goto err;
 
-	gf->lenBlkStrtHash = sf.lenHash;
-	gf->blkStrtHash = calloc(1, gf->lenBlkStrtHash);
-	if(read(fd, gf->blkStrtHash, gf->lenBlkStrtHash)
-		!= gf->lenBlkStrtHash) {
-		free(gf->blkStrtHash);
+	gf->x_prev = malloc(sizeof(imprint_t));
+	if (gf->x_prev == NULL) goto err;
+	gf->x_prev->len = sf.lenHash;
+	gf->x_prev->hashID = sf.hashID;
+	gf->x_prev->data = calloc(1, gf->x_prev->len);
+	if (gf->x_prev->data == NULL) {
+		free(gf->x_prev);
+		gf->x_prev = NULL;
+		goto err;
+	}
+
+	if(read(fd, gf->x_prev->data, gf->x_prev->len)
+		!= gf->x_prev->len) {
+		rsgtimprintDel(gf->x_prev);
+		gf->x_prev = NULL;
 		goto err;
 	}
 	close(fd);
 return;
 
 err:
-	gf->lenBlkStrtHash = hashOutputLengthOctets(gf->hashAlg);
-	gf->blkStrtHash = calloc(1, gf->lenBlkStrtHash);
+	gf->x_prev = malloc(sizeof(imprint_t));
+	gf->x_prev->hashID = hashIdentifier(gf->hashAlg);
+	gf->x_prev->len = hashOutputLengthOctets(gf->hashAlg);
+	gf->x_prev->data = calloc(1, gf->x_prev->len);
 }
 
 /* persist all information that we need to re-open and append
@@ -543,6 +560,8 @@ rsgtCtxOpenFile(gtctx ctx, unsigned char *logfn)
 	gf->statefilename = (uchar*) strdup(fn);
 	if(tlvOpen(gf, LOGSIGHDR, sizeof(LOGSIGHDR)-1) != 0) {
 		reportErr(ctx, "signature file open failed");
+		/* Free memory */
+		free(gf);
 		gf = NULL;
 	}
 done:	return gf;
@@ -587,7 +606,6 @@ rsgtfileDestruct(gtfile gf)
 	free(gf->sigfilename);
 	free(gf->statefilename);
 	free(gf->IV);
-	free(gf->blkStrtHash);
 	rsgtimprintDel(gf->x_prev);
 	free(gf);
 done:	return r;
@@ -608,7 +626,7 @@ sigblkInit(gtfile gf)
 {
 	if(gf == NULL) goto done;
 	seedIV(gf);
-	memset(gf->roots_valid, 0, sizeof(gf->roots_valid)/sizeof(char));
+	memset(gf->roots_valid, 0, sizeof(gf->roots_valid));
 	gf->nRoots = 0;
 	gf->nRecords = 0;
 	gf->bInBlk = 1;
@@ -620,28 +638,25 @@ done:	return;
 static inline void
 bufAddIV(gtfile gf, uchar *buf, size_t *len)
 {
-	memcpy(buf+*len, gf->IV, hashOutputLengthOctets(gf->hashAlg));
-	*len += sizeof(gf->IV);
+	int hashlen;
+
+	hashlen = hashOutputLengthOctets(gf->hashAlg);
+
+	memcpy(buf+*len, gf->IV, hashlen);
+	*len += hashlen;
 }
 
 
 /* concat: add imprint to buffer */
 static inline void
-bufAddImprint(gtfile gf, uchar *buf, size_t *len, imprint_t *imp)
+bufAddImprint(uchar *buf, size_t *len, imprint_t *imp)
 {
-	if(imp == NULL) {
-	/* TODO: how to get the REAL HASH ID? --> add field? */
-		buf[*len] = hashIdentifier(gf->hashAlg);
-		++(*len);
-		memcpy(buf+*len, gf->blkStrtHash, gf->lenBlkStrtHash);
-		*len += gf->lenBlkStrtHash;
-	} else {
-		buf[*len] = imp->hashID;
-		++(*len);
-		memcpy(buf+*len, imp->data, imp->len);
-		*len += imp->len;
-	}
+	buf[*len] = imp->hashID;
+	++(*len);
+	memcpy(buf+*len, imp->data, imp->len);
+	*len += imp->len;
 }
+
 /* concat: add hash to buffer */
 static inline void
 bufAddHash(gtfile gf, uchar *buf, size_t *len, GTDataHash *hash)
@@ -668,7 +683,7 @@ hash_m(gtfile gf, GTDataHash **m)
 	size_t len = 0;
 	int r = 0;
 
-	bufAddImprint(gf, concatBuf, &len, gf->x_prev);
+	bufAddImprint(concatBuf, &len, gf->x_prev);
 	bufAddIV(gf, concatBuf, &len);
 	rgt = GTDataHash_create(gf->hashAlg, concatBuf, len, m);
 	if(rgt != GT_OK) {
@@ -725,12 +740,14 @@ sigblkAddRecord(gtfile gf, const uchar *rec, const size_t len)
 	if(gf == NULL || gf->disabled) goto done;
 	if((ret = hash_m(gf, &m)) != 0) goto done;
 	if((ret = hash_r(gf, &r, rec, len)) != 0) goto done;
+	if(gf->nRecords == 0) 
+		tlvWriteBlockHdr(gf);
 	if(gf->bKeepRecordHashes)
-		tlvWriteHash(gf, 0x0900, r);
+		tlvWriteHash(gf, 0x0902, r);
 	if((ret = hash_node(gf, &x, m, r, 1)) != 0) goto done; /* hash leaf */
 	/* persists x here if Merkle tree needs to be persisted! */
 	if(gf->bKeepTreeHashes)
-		tlvWriteHash(gf, 0x0901, x);
+		tlvWriteHash(gf, 0x0903, x);
 	rsgtimprintDel(gf->x_prev);
 	gf->x_prev = rsgtImprintFromGTDataHash(x);
 	/* add x to the forest as new leaf, update roots list */
@@ -750,7 +767,7 @@ sigblkAddRecord(gtfile gf, const uchar *rec, const size_t len)
 			GTDataHash_free(t_del);
 			if(ret != 0) goto done;
 			if(gf->bKeepTreeHashes)
-				tlvWriteHash(gf, 0x0901, t);
+				tlvWriteHash(gf, 0x0903, t);
 		}
 	}
 	if(t != NULL) {
@@ -841,10 +858,6 @@ sigblkFinish(gtfile gf)
 	if((ret = timestampIt(gf, root)) != 0) goto done;
 
 	GTDataHash_free(root);
-	free(gf->blkStrtHash);
-	gf->lenBlkStrtHash = gf->x_prev->len;
-	gf->blkStrtHash = malloc(gf->lenBlkStrtHash);
-	memcpy(gf->blkStrtHash, gf->x_prev->data, gf->x_prev->len);
 done:
 	gf->bInBlk = 0;
 	return ret;
