@@ -61,7 +61,7 @@ struct ksifile_s {
 	uint8_t disabled; /* permits to disable this file --> set to 1 */
 	uint64_t blockSizeLimit;
 	uint8_t *IV; /* initial value for blinding masks */
-	imprint_t *x_prev; /* last leaf hash (maybe of previous block) --> preserve on term */
+	imprint_t *x_prev;		/* last leaf hash (maybe of previous block)		--> preserve on term */
 	unsigned char *sigfilename;
 	unsigned char *statefilename;
 	int fd;
@@ -119,6 +119,7 @@ struct rsksistatefile {
 };
 
 /* error states */
+#define RSGTE_SUCCESS 0 /* Success state */
 #define RSGTE_IO 1 	/* any kind of io error */
 #define RSGTE_FMT 2	/* data fromat error */
 #define RSGTE_INVLTYP 3	/* invalid TLV type record (unexcpected at this point) */
@@ -142,6 +143,7 @@ struct rsksistatefile {
 #define RSGTE_HASH_CREATE 20 /* error creating a hash */
 #define RSGTE_END_OF_SIG 21 /* unexpected end of signature - more log line exist */
 #define RSGTE_END_OF_LOG 22 /* unexpected end of log file - more signatures exist */
+#define RSGTE_EXTRACT_HASH 23 /* error extracting hashes for record */
 
 /* the following function maps RSGTE_* state to a string - must be updated
  * whenever a new state is added.
@@ -152,7 +154,7 @@ static inline char *
 RSKSIE2String(int err)
 {
 	switch(err) {
-	case 0:
+	case RSGTE_SUCCESS:
 		return "success";
 	case RSGTE_IO:
 		return "i/o error";
@@ -198,6 +200,8 @@ RSKSIE2String(int err)
 		return "unexpected end of signature";
 	case RSGTE_END_OF_LOG:
 		return "unexpected end of log";
+	case RSGTE_EXTRACT_HASH:
+		return "either record-hash, left-hash or right-hash was empty";
 	default:
 		return "unknown error";
 	}
@@ -220,8 +224,6 @@ hashOutputLengthOctetsKSI(uint8_t hashID)
 		return 48;
 	case KSI_HASHALG_SHA2_512: /** The SHA-512 algorithm. */
 		return 64;
-	case KSI_HASHALG_RIPEMD_256: /** The RIPEMD-256 algorithm. */
-		return 32;
 	case KSI_HASHALG_SHA3_244: /** The SHA3-244 algorithm. */
 		return 28;
 	case KSI_HASHALG_SHA3_256: /** The SHA3-256 algorithm. */
@@ -252,8 +254,6 @@ hashIdentifierKSI(KSI_HashAlgorithm hashID)
 		return 0x04;
 	case KSI_HASHALG_SHA2_512: /** The SHA-512 algorithm. */
 		return 0x05;
-	case KSI_HASHALG_RIPEMD_256: /** The RIPEMD-256 algorithm. */
-		return 0x06;
 	case KSI_HASHALG_SHA3_244: /** The SHA3-244 algorithm. */
 		return 0x07;
 	case KSI_HASHALG_SHA3_256: /** The SHA3-256 algorithm. */
@@ -283,8 +283,6 @@ hashAlgNameKSI(uint8_t hashID)
 		return "SHA2-384";
 	case KSI_HASHALG_SHA2_512:
 		return "SHA2-512";
-	case KSI_HASHALG_RIPEMD_256:
-		return "RIPEMD-256";
 	case KSI_HASHALG_SHA3_244:
 		return "SHA3-224";
 	case KSI_HASHALG_SHA3_256:
@@ -314,8 +312,6 @@ hashID2AlgKSI(uint8_t hashID)
 		return KSI_HASHALG_SHA2_384;
 	case 0x05:
 		return KSI_HASHALG_SHA2_512;
-	case 0x06:
-		return KSI_HASHALG_RIPEMD_256;
 	case 0x07:
 		return KSI_HASHALG_SHA3_244;
 	case 0x08:
@@ -357,13 +353,15 @@ int rsksiInit(char *usragent);
 void rsksiExit(void);
 rsksictx rsksiCtxNew(void);
 void rsksisetErrFunc(rsksictx ctx, void (*func)(void*, unsigned char *), void *usrptr);
+void reportKSIAPIErr(rsksictx ctx, ksifile ksi, char *apiname, int ecode); 
 ksifile rsksiCtxOpenFile(rsksictx ctx, unsigned char *logfn);
 int rsksifileDestruct(ksifile ksi);
 void rsksiCtxDel(rsksictx ctx);
 void sigblkInitKSI(ksifile ksi);
 int sigblkAddRecordKSI(ksifile ksi, const unsigned char *rec, const size_t len);
 int sigblkFinishKSI(ksifile ksi);
-imprint_t * rsksiImprintFromKSI_DataHash(ksifile ksi, KSI_DataHash *hash);
+int rsksiIntoImprintFromKSI_DataHash(imprint_t* imp, ksifile ksi, KSI_DataHash *hash);
+imprint_t* rsksiImprintFromKSI_DataHash(ksifile ksi, KSI_DataHash *hash);
 void rsksiimprintDel(imprint_t *imp);
 /* reader functions */
 int rsksi_tlvrdHeader(FILE *fp, unsigned char *hdr);
@@ -371,13 +369,16 @@ int rsksi_tlvrd(FILE *fp, tlvrecord_t *rec, void *obj);
 void rsksi_tlvprint(FILE *fp, uint16_t tlvtype, void *obj, uint8_t verbose);
 void rsksi_printBLOCK_HDR(FILE *fp, block_hdr_t *bh, uint8_t verbose);
 void rsksi_printBLOCK_SIG(FILE *fp, block_sig_t *bs, uint8_t verbose);
-int rsksi_getBlockParams(FILE *fp, uint8_t bRewind, block_sig_t **bs, block_hdr_t **bh, uint8_t *bHasRecHashes, uint8_t *bHasIntermedHashes);
-int rsksi_chkFileHdr(FILE *fp, char *expect);
+int rsksi_getBlockParams(ksifile ksi, FILE *fp, uint8_t bRewind, block_sig_t **bs, block_hdr_t **bh, uint8_t *bHasRecHashes, uint8_t *bHasIntermedHashes);
+int rsksi_getExcerptBlockParams(ksifile ksi, FILE *fp, uint8_t bRewind, block_sig_t **bs, block_hdr_t **bh); 
+int rsksi_chkFileHdr(FILE *fp, char *expect, uint8_t verbose);
 ksifile rsksi_vrfyConstruct_gf(void);
 void rsksi_vrfyBlkInit(ksifile ksi, block_hdr_t *bh, uint8_t bHasRecHashes, uint8_t bHasIntermedHashes);
 int rsksi_vrfy_nextRec(ksifile ksi, FILE *sigfp, FILE *nsigfp, unsigned char *rec, size_t len, ksierrctx_t *ectx);
-int verifyBLOCK_HDRKSI(FILE *sigfp, FILE *nsigfp);
-int verifyBLOCK_SIGKSI(block_sig_t *bs, ksifile ksi, FILE *sigfp, FILE *nsigfp, uint8_t bExtend, ksierrctx_t *ectx);
+	int rsksi_vrfy_nextRecExtract(ksifile ksi, FILE *sigfp, FILE *nsigfp, unsigned char *rec, size_t len, ksierrctx_t *ectx, block_hashchain_t *hashchain, int storehashchain); 
+	int rsksi_vrfy_nextHashChain(ksifile ksi, block_sig_t *bs, FILE *sigfp, unsigned char *rec, size_t len, ksierrctx_t *ectx);
+int verifyBLOCK_HDRKSI(ksifile ksi, FILE *sigfp, FILE *nsigfp, tlvrecord_t* tlvrec);
+int verifyBLOCK_SIGKSI(block_sig_t *bs, ksifile ksi, FILE *sigfp, FILE *nsigfp, uint8_t bExtend, KSI_DataHash *ksiHash, ksierrctx_t *ectx);
 void rsksi_errctxInit(ksierrctx_t *ectx);
 void rsksi_errctxExit(ksierrctx_t *ectx);
 void rsksi_errctxSetErrRec(ksierrctx_t *ectx, char *rec);
@@ -385,12 +386,27 @@ void rsksi_errctxFrstRecInBlk(ksierrctx_t *ectx, char *rec);
 void rsksi_objfree(uint16_t tlvtype, void *obj);
 void rsksi_set_debug(int iDebug); 
 int rsksi_ConvertSigFile(char* name, FILE *oldsigfp, FILE *newsigfp, int verbose); 
+	
+	int rsksi_WriteHashChain(FILE *newsigfp, block_hashchain_t *hashchain, block_sig_t *bsIn, int verbose); 
+	int rsksi_ExtractBlockSignature(FILE *newsigfp, ksifile ksi, block_sig_t *bsIn, ksierrctx_t *ectx, int verbose); 
+	int rsksi_tlvwrite(FILE *fp, tlvrecord_t *rec); 
+	int rsksi_tlvRecDecode(tlvrecord_t *rec, void *obj); 
+	int rsksi_tlvDecodeIMPRINT(tlvrecord_t *rec, imprint_t **imprint); 
+	int rsksi_tlvDecodeHASHCHAIN(tlvrecord_t *rec, block_hashchain_t **blhashchain); 
+	int verifySigblkFinish(ksifile ksi, KSI_DataHash **pRoot); 
+	int verifySigblkFinishChain(ksifile ksi, block_hashchain_t *hashchain, KSI_DataHash **pRoot, ksierrctx_t *ectx); 
+
+	void outputHash(FILE *fp, const char *hdr, const uint8_t *data, const uint16_t len, const uint8_t verbose); 
+	void outputKSIHash(FILE *fp, char *hdr, const KSI_DataHash *const __restrict__ hash, const uint8_t verbose); 
 
 /* TODO: replace these? */
 int hash_m_ksi(ksifile ksi, KSI_DataHash **m);
 int hash_r_ksi(ksifile ksi, KSI_DataHash **r, const unsigned char *rec, const size_t len);
 int hash_node_ksi(ksifile ksi, KSI_DataHash **node, KSI_DataHash *m, KSI_DataHash *r, uint8_t level);
-extern char *rsksi_read_puburl; /**< url of publication server */
+extern char *rsksi_read_puburl;		/**< url of publication server */
+extern char *rsksi_extend_puburl;	/**< url of extension server */
+extern char *rsksi_userid;			/**< userid for extension server */
+extern char *rsksi_userkey;			/**< userkey for extension server */
 extern uint8_t rsksi_read_showVerified;
 extern int RSKSI_FLAG_TLV16_RUNTIME;
 extern int RSKSI_FLAG_NONCRIT_RUNTIME; 
