@@ -4,7 +4,7 @@
  *
  * File begun on 2007-07-25 by RGerhards
  *
- * Copyright 2007-2012 Adiscon GmbH.
+ * Copyright 2007-2015 Adiscon GmbH.
  *
  * This file is part of the rsyslog runtime library.
  *
@@ -276,8 +276,9 @@ static rsRetVal endTransaction(wrkrInstanceData_t __attribute__((unused)) *pWrkr
 /* doAction()
  */
 #define BEGINdoAction \
-static rsRetVal doAction(uchar __attribute__((unused)) **ppString, wrkrInstanceData_t __attribute__((unused)) *pWrkrData)\
+static rsRetVal doAction(void * pMsgData, wrkrInstanceData_t __attribute__((unused)) *pWrkrData)\
 {\
+	uchar **ppString = (uchar **) pMsgData; \
 	DEFiRet;
 
 #define CODESTARTdoAction \
@@ -287,6 +288,14 @@ static rsRetVal doAction(uchar __attribute__((unused)) **ppString, wrkrInstanceD
 	RETiRet;\
 }
 
+/* below is a variant of doAction where the passed-in data is not the common
+ * case of string.
+ */
+#define BEGINdoAction_NoStrings \
+static rsRetVal doAction(void * pMsgData, wrkrInstanceData_t __attribute__((unused)) *pWrkrData)\
+{\
+	DEFiRet;
+
 
 /* dbgPrintInstInfo()
  * Extra comments:
@@ -1050,7 +1059,7 @@ static rsRetVal afterRun(void)\
  * This function is optional. Currently, it is available to output plugins
  * only, but may be made available to other types of plugins in the future.
  * A plugin does not need to define this entry point. If if does, it gets
- * called when a non-restart type of HUP is done. A plugin should register
+ * called when a HUP at the action level is to be done. A plugin should register
  * this function so that it can close files, connection or other ressources
  * on HUP - if it can be assume the user wanted to do this as a part of HUP
  * processing. Note that the name "HUP" has historical reasons, it stems back
@@ -1074,6 +1083,26 @@ static rsRetVal doHUP(instanceData __attribute__((unused)) *pData)\
 }
 
 
+/* doHUPWrkr()
+ * This is like doHUP(), but on an action worker level.
+ * rgerhards, 2015-03-25
+ */
+#define CODEqueryEtryPt_doHUPWrkr \
+	else if(!strcmp((char*) name, "doHUPWrkr")) {\
+		*pEtryPoint = doHUPWrkr;\
+	}
+#define BEGINdoHUPWrkr \
+static rsRetVal doHUPWrkr(wrkrInstanceData_t __attribute__((unused)) *pWrkrData)\
+{\
+	DEFiRet;
+
+#define CODESTARTdoHUPWrkr 
+
+#define ENDdoHUPWrkr \
+	RETiRet;\
+}
+
+
 /* SetShutdownImmdtPtr()
  * This function is optional. If defined by an output plugin, it is called 
  * each time the action is invoked to set the "ShutdownImmediate" pointer,
