@@ -247,7 +247,8 @@ static void moduleDestruct(modInfo_t *pThis)
 	free(pThis->cnfName);
 	if(pThis->pModHdlr != NULL) {
 #	ifdef	VALGRIND
-#		warning "dlclose disabled for valgrind"
+		DBGPRINTF("moduleDestruct: compiled with valgrind, do "
+			"not unload module\n");
 #	else
 		if (pThis->eKeepType == eMOD_NOKEEP) {
 			dlclose(pThis->pModHdlr);
@@ -266,7 +267,7 @@ static rsRetVal queryCoreFeatureSupport(int *pBool, unsigned uFeat)
 {
 	DEFiRet;
 
-	if((pBool == NULL))
+	if(pBool == NULL)
 		ABORT_FINALIZE(RS_RET_PARAM_ERROR);
 
 	*pBool = (uFeat & CORE_FEATURE_BATCHING) ? 1 : 0;
@@ -1129,7 +1130,7 @@ Load(uchar *pModName, sbool bConfLoad, struct nvlst *lst)
 					free(pPathBuf);
 				/* we always alloc enough memory for everything we potentiall need to add */
 				lenPathBuf = PATHBUF_OVERHEAD;
-				CHKmalloc(pPathBuf = malloc(sizeof(uchar)*lenPathBuf));
+				CHKmalloc(pPathBuf = malloc(lenPathBuf));
 			}
 			*pPathBuf = '\0';	/* we do not need to append the path - its already in the module name */
 			iPathLen = 0;
@@ -1152,7 +1153,7 @@ Load(uchar *pModName, sbool bConfLoad, struct nvlst *lst)
 					free(pPathBuf);
 				/* we always alloc enough memory for everything we potentiall need to add */
 				lenPathBuf = iPathLen + PATHBUF_OVERHEAD;
-				CHKmalloc(pPathBuf = malloc(sizeof(uchar)*lenPathBuf));
+				CHKmalloc(pPathBuf = malloc(lenPathBuf));
 			}
 
 			memcpy((char *) pPathBuf, (char *)pModDirCurr, iPathLen);
