@@ -192,7 +192,7 @@ Wait(nssel_t *pThis, int *piNumReady)
  * rgerhards, 2008-04-23
  */
 static rsRetVal
-IsReady(nssel_t *pThis, netstrm_t *pStrm, nsdsel_waitOp_t waitOp, int *pbIsReady, int *piNumReady)
+IsReady(nssel_t *pThis, netstrm_t *pStrm, nsdsel_waitOp_t waitOp, int *pbIsReady, int __attribute__((unused)) *piNumReady)
 {
 	DEFiRet;
 	ISOBJ_TYPE_assert(pThis, nssel);
