@@ -70,6 +70,7 @@
 #include "netstrm.h"
 #include "nssel.h"
 #include "errmsg.h"
+#include "prop.h"
 #include "unicode-helper.h"
 
 MODULE_TYPE_LIB
@@ -89,6 +90,7 @@ DEFobjCurrIf(net)
 DEFobjCurrIf(netstrms)
 DEFobjCurrIf(netstrm)
 DEFobjCurrIf(nssel)
+DEFobjCurrIf(prop)
 
 /* forward definitions */
 static rsRetVal create_strm_socket(strmsrv_t *pThis);
@@ -167,7 +169,11 @@ addNewLstnPort(strmsrv_t *pThis, uchar *pszPort)
 	CHKmalloc(pEntry = MALLOC(sizeof(strmLstnPortList_t)));
 	pEntry->pszPort = pszPort;
 	pEntry->pSrv = pThis;
-	CHKmalloc(pEntry->pszInputName = ustrdup(pThis->pszInputName));
+	if((pEntry->pszInputName = ustrdup(pThis->pszInputName)) == NULL) {
+		DBGPRINTF("strmsrv/addNewLstnPort: OOM in strdup()\n");
+		free(pEntry);
+		ABORT_FINALIZE(RS_RET_OUT_OF_MEMORY);
+	}
 
 	/* and add to list */
 	pEntry->pNext = pThis->pLstnPorts;
@@ -418,7 +424,7 @@ SessAccept(strmsrv_t *pThis, strmLstnPortList_t *pLstnInfo, strms_sess_t **ppSes
 	int iSess = -1;
 	struct sockaddr_storage *addr;
 	uchar *fromHostFQDN = NULL;
-	uchar *fromHostIP = NULL;
+	prop_t *ip = NULL;
 
 	ISOBJ_TYPE_assert(pThis, strmsrv);
 	assert(pLstnInfo != NULL);
@@ -434,6 +440,9 @@ SessAccept(strmsrv_t *pThis, strmLstnPortList_t *pLstnInfo, strms_sess_t **ppSes
 	}
 
 	if(pThis->bUseKeepAlive) {
+		CHKiRet(netstrm.SetKeepAliveProbes(pNewStrm, pThis->iKeepAliveProbes));
+		CHKiRet(netstrm.SetKeepAliveTime(pNewStrm, pThis->iKeepAliveTime));
+		CHKiRet(netstrm.SetKeepAliveIntvl(pNewStrm, pThis->iKeepAliveIntvl));
 		CHKiRet(netstrm.EnableKeepAlive(pNewStrm));
 	}
 
@@ -444,7 +453,7 @@ SessAccept(strmsrv_t *pThis, strmLstnPortList_t *pLstnInfo, strms_sess_t **ppSes
 
 	/* get the host name */
 	CHKiRet(netstrm.GetRemoteHName(pNewStrm, &fromHostFQDN));
-	CHKiRet(netstrm.GetRemoteIP(pNewStrm, &fromHostIP));
+	CHKiRet(netstrm.GetRemoteIP(pNewStrm, &ip));
 	CHKiRet(netstrm.GetRemAddr(pNewStrm, &addr));
 	/* TODO: check if we need to strip the domain name here -- rgerhards, 2008-04-24 */
 
@@ -467,8 +476,8 @@ SessAccept(strmsrv_t *pThis, strmLstnPortList_t *pLstnInfo, strms_sess_t **ppSes
 	 */
 	CHKiRet(strms_sess.SetHost(pSess, fromHostFQDN));
 	fromHostFQDN = NULL; /* we handed this string over */
-	CHKiRet(strms_sess.SetHostIP(pSess, fromHostIP));
-	fromHostIP = NULL; /* we handed this string over */
+	CHKiRet(strms_sess.SetHostIP(pSess, ip));
+	ip = NULL; /* we handed this string over */
 	CHKiRet(strms_sess.SetStrm(pSess, pNewStrm));
 	pNewStrm = NULL; /* prevent it from being freed in error handler, now done in strms_sess! */
 	CHKiRet(strms_sess.ConstructFinalize(pSess));
@@ -489,7 +498,8 @@ finalize_it:
 		if(pNewStrm != NULL)
 			netstrm.Destruct(&pNewStrm);
 		free(fromHostFQDN);
-		free(fromHostIP);
+		if(ip != NULL)
+			prop.Destruct(&ip);
 	}
 
 	RETiRet;
@@ -770,6 +780,33 @@ SetKeepAlive(strmsrv_t *pThis, int iVal)
 	RETiRet;
 }
 
+static rsRetVal
+SetKeepAliveIntvl(strmsrv_t *pThis, int iVal)
+{
+	DEFiRet;
+	DBGPRINTF("strmsrv: keep-alive set to %d\n", iVal);
+	pThis->iKeepAliveIntvl = iVal;
+	RETiRet;
+}
+
+static rsRetVal
+SetKeepAliveProbes(strmsrv_t *pThis, int iVal)
+{
+	DEFiRet;
+	DBGPRINTF("strmsrv: keep-alive set to %d\n", iVal);
+	pThis->iKeepAliveProbes = iVal;
+	RETiRet;
+}
+
+static rsRetVal
+SetKeepAliveTime(strmsrv_t *pThis, int iVal)
+{
+	DEFiRet;
+	DBGPRINTF("strmsrv: keep-alive set to %d\n", iVal);
+	pThis->iKeepAliveTime = iVal;
+	RETiRet;
+}
+
 static rsRetVal
 SetOnCharRcvd(strmsrv_t *pThis, rsRetVal (*OnCharRcvd)(strms_sess_t*, uchar))
 {
@@ -873,12 +910,13 @@ CODESTARTobjQueryInterface(strmsrv)
 	pIf->Construct = strmsrvConstruct;
 	pIf->ConstructFinalize = strmsrvConstructFinalize;
 	pIf->Destruct = strmsrvDestruct;
-
 	pIf->configureSTRMListen = configureSTRMListen;
 	pIf->create_strm_socket = create_strm_socket;
 	pIf->Run = Run;
-
 	pIf->SetKeepAlive = SetKeepAlive;
+	pIf->SetKeepAliveIntvl = SetKeepAliveIntvl;
+	pIf->SetKeepAliveProbes = SetKeepAliveProbes;
+	pIf->SetKeepAliveTime = SetKeepAliveTime;
 	pIf->SetUsrP = SetUsrP;
 	pIf->SetInputName = SetInputName;
 	pIf->SetSessMax = SetSessMax;
@@ -908,6 +946,7 @@ CODESTARTObjClassExit(strmsrv)
 	objRelease(strms_sess, DONT_LOAD_LIB);
 	objRelease(conf, CORE_COMPONENT);
 	objRelease(glbl, CORE_COMPONENT);
+	objRelease(prop, CORE_COMPONENT);
 	objRelease(errmsg, CORE_COMPONENT);
 	objRelease(netstrms, DONT_LOAD_LIB);
 	objRelease(nssel, DONT_LOAD_LIB);
@@ -930,6 +969,7 @@ BEGINObjClassInit(strmsrv, 1, OBJ_IS_LOADABLE_MODULE) /* class, version - CHANGE
 	CHKiRet(objUse(strms_sess, DONT_LOAD_LIB));
 	CHKiRet(objUse(conf, CORE_COMPONENT));
 	CHKiRet(objUse(glbl, CORE_COMPONENT));
+	CHKiRet(objUse(prop, CORE_COMPONENT));
 
 	/* set our own handlers */
 	OBJSetMethodHandler(objMethod_DEBUGPRINT, strmsrvDebugPrint);
