@@ -72,7 +72,7 @@ struct wti_s {
 	actWrkrInfo_t *actWrkrInfo; /* *array* of action wrkr infos for all actions
 				      (sized for max nbr of actions in config!) */
 	pthread_cond_t pcondBusy; /* condition to wake up the worker, protected by pmutUsr in wtp */
-	DEF_ATOMIC_HELPER_MUT(mutIsRunning);
+	DEF_ATOMIC_HELPER_MUT(mutIsRunning)
 	struct {
 		uint8_t bPrevWasSuspended;
 		uint8_t bDoAutoCommit; /* do a commit after each message
@@ -177,21 +177,15 @@ wtiNewIParam(wti_t *const pWti, action_t *const pAction, actWrkrIParams_t **pipa
 
 	if(wrkrInfo->p.tx.currIParam == wrkrInfo->p.tx.maxIParams) {
 		/* we need to extend */
-		dbgprintf("DDDD: extending iparams, curr max %d\n", wrkrInfo->p.tx.maxIParams);
 		newMax = (wrkrInfo->p.tx.maxIParams == 0) ? CONF_IPARAMS_BUFSIZE
 							  : 2 * wrkrInfo->p.tx.maxIParams;
-dbgprintf("DDDD: realloc size %u\n", sizeof(actWrkrIParams_t) * pAction->iNumTpls * newMax);
 		CHKmalloc(iparams = realloc(wrkrInfo->p.tx.iparams,
 					    sizeof(actWrkrIParams_t) * pAction->iNumTpls * newMax));
-dbgprintf("DDDD: setting memory base %u, lenBytes %u, len %u\n", wrkrInfo->p.tx.currIParam * pAction->iNumTpls,
-		       sizeof(actWrkrIParams_t) * pAction->iNumTpls * (newMax - wrkrInfo->p.tx.maxIParams),
-		       pAction->iNumTpls * (newMax - wrkrInfo->p.tx.maxIParams));
 		memset(iparams + (wrkrInfo->p.tx.currIParam * pAction->iNumTpls), 0,
 		       sizeof(actWrkrIParams_t) * pAction->iNumTpls * (newMax - wrkrInfo->p.tx.maxIParams));
 		wrkrInfo->p.tx.iparams = iparams;
 		wrkrInfo->p.tx.maxIParams = newMax;
 	}
-dbgprintf("DDDD: adding param  %d for action %d\n", wrkrInfo->p.tx.currIParam, pAction->iActionNbr);
 	*piparams = wrkrInfo->p.tx.iparams + wrkrInfo->p.tx.currIParam * pAction->iNumTpls;
 	++wrkrInfo->p.tx.currIParam;
 
