@@ -1,3 +1,4 @@
+#!/bin/bash
 # This tests async writing with only a small set of data. That
 # shall result in data staying in buffers until shutdown, what
 # then will trigger some somewhat complex logic in the stream
@@ -13,14 +14,14 @@
 # This file is part of the rsyslog project, released  under GPLv3
 echo ===============================================================================
 echo TEST: \[asynwr_small.sh\]: test for async file writing for few messages
-source $srcdir/diag.sh init
+. $srcdir/diag.sh init
 # uncomment for debugging support:
 #export RSYSLOG_DEBUG="debug nostdout noprintmutexaction"
 #export RSYSLOG_DEBUGLOG="log"
-source $srcdir/diag.sh startup asynwr_small.conf
+. $srcdir/diag.sh startup asynwr_small.conf
 # send 4000 messages
-source $srcdir/diag.sh tcpflood -m2
-source $srcdir/diag.sh shutdown-when-empty # shut down rsyslogd when done processing messages
-source $srcdir/diag.sh wait-shutdown       # and wait for it to terminate
-source $srcdir/diag.sh seq-check 0 1
-source $srcdir/diag.sh exit
+. $srcdir/diag.sh tcpflood -m2
+. $srcdir/diag.sh shutdown-when-empty # shut down rsyslogd when done processing messages
+. $srcdir/diag.sh wait-shutdown       # and wait for it to terminate
+. $srcdir/diag.sh seq-check 0 1
+. $srcdir/diag.sh exit
