@@ -1,15 +1,16 @@
+#!/bin/bash
 # This file is part of the rsyslog project, released under ASL 2.0
 echo ===============================================================================
 echo \[es-bulk-errfile-popul-def-interleaved\]: basic test for elasticsearch functionality
-source $srcdir/diag.sh init
-source $srcdir/diag.sh es-init
+. $srcdir/diag.sh init
+. $srcdir/diag.sh es-init
 echo '{ "name" : "foo" }
 {"name": bar"}
 {"name": "baz"}
 {"name": foz"}' > inESData.inputfile
-source $srcdir/diag.sh startup es-bulk-errfile-popul-def-interleaved.conf
-source $srcdir/diag.sh shutdown-when-empty
-source $srcdir/diag.sh wait-shutdown
+. $srcdir/diag.sh startup es-bulk-errfile-popul-def-interleaved.conf
+. $srcdir/diag.sh shutdown-when-empty
+. $srcdir/diag.sh wait-shutdown
 rm -f inESData.inputfile
 
 python $srcdir/elasticsearch-error-format-check.py interleaved
@@ -19,4 +20,4 @@ then
     echo "error: Format for error file different! " $?
     exit 1
 fi
-source $srcdir/diag.sh exit
+. $srcdir/diag.sh exit
