@@ -1,7 +1,8 @@
+#!/bin/bash
 echo \[fieldtest.sh\]: test fieldtest via udp
-source $srcdir/diag.sh init
+. $srcdir/diag.sh init
 $srcdir/killrsyslog.sh # kill rsyslogd if it runs for some reason
-source $srcdir/diag.sh generate-HOSTNAME
+. $srcdir/diag.sh generate-HOSTNAME
 
 ./nettester -tfield1 -iudp
 if [ "$?" -ne "0" ]; then
@@ -13,4 +14,4 @@ echo test fieldtest via tcp
 if [ "$?" -ne "0" ]; then
   exit 1
 fi
-source $srcdir/diag.sh exit
+. $srcdir/diag.sh exit
