@@ -1,7 +1,12 @@
 #!/bin/bash
 # This is part of the rsyslog testbench, licensed under ASL 2.0
 echo ======================================================================
-echo [imfile-readmode2-with-persists.sh]
+# Check if inotify header exist
+if [ -n "$(find /usr/include -name 'inotify.h' -print -quit)" ]; then
+	echo [imfile-readmode2-with-persists.sh]
+else
+	exit 77 # no inotify available, skip this test
+fi
 . $srcdir/diag.sh init
 . $srcdir/diag.sh startup imfile-readmode2-with-persists.conf
 
