@@ -2,10 +2,14 @@
 #include <stdlib.h>
 #include <string.h>
 #include <sys/types.h>
+#include <sys/stat.h>
 #include <sys/socket.h>
 #include <fcntl.h>
 #include <unistd.h>
 #include <arpa/inet.h>
+#if defined(__FreeBSD__)
+#include <netinet/in.h>
+#endif
 
 static void
 errout(char *reason)
