@@ -1,3 +1,4 @@
+#!/bin/bash
 # test for omruleset. What we do is have the main queue forward 
 # all messages to a secondary ruleset via omruleset, which then does
 # the actual file write. We check if all messages arrive at the file, 
@@ -8,12 +9,12 @@
 # This file is part of the rsyslog project, released under GPLv3
 echo ===============================================================================
 echo \[omruleset-queue.sh\]: test for omruleset functionality with a ruleset queue
-source $srcdir/diag.sh init
-source $srcdir/diag.sh startup omruleset-queue.conf
-source $srcdir/diag.sh injectmsg  0 20000
+. $srcdir/diag.sh init
+. $srcdir/diag.sh startup omruleset-queue.conf
+. $srcdir/diag.sh injectmsg  0 20000
 echo doing shutdown
-source $srcdir/diag.sh shutdown-when-empty
+. $srcdir/diag.sh shutdown-when-empty
 echo wait on shutdown
-source $srcdir/diag.sh wait-shutdown 
-source $srcdir/diag.sh seq-check 0 19999
-source $srcdir/diag.sh exit
+. $srcdir/diag.sh wait-shutdown 
+. $srcdir/diag.sh seq-check 0 19999
+. $srcdir/diag.sh exit
