@@ -1,3 +1,4 @@
+#!/bin/bash
 # Test for the pipe output action.
 # will create a fifo in the current directory, write to it and
 # then do the usual sequence checks.
@@ -7,7 +8,7 @@ echo \[pipeaction.sh\]: testing pipe output action
 
 # create the pipe and start a background process that copies data from 
 # it to the "regular" work file
-source $srcdir/diag.sh init
+. $srcdir/diag.sh init
 rm -f rsyslog-testbench-fifo
 mkfifo rsyslog-testbench-fifo
 cp rsyslog-testbench-fifo rsyslog.out.log &
@@ -15,12 +16,12 @@ CPPROCESS=$!
 echo background cp process id is $CPPROCESS
 
 # now do the usual run
-source $srcdir/diag.sh startup pipeaction.conf
+. $srcdir/diag.sh startup pipeaction.conf
 # 20000 messages should be enough
-#source $srcdir/diag.sh tcpflood -m20000
-source $srcdir/diag.sh injectmsg 0 20000
-source $srcdir/diag.sh shutdown-when-empty # shut down rsyslogd when done processing messages
-source $srcdir/diag.sh wait-shutdown
+#. $srcdir/diag.sh tcpflood -m20000
+. $srcdir/diag.sh injectmsg 0 20000
+. $srcdir/diag.sh shutdown-when-empty # shut down rsyslogd when done processing messages
+. $srcdir/diag.sh wait-shutdown
 
 # wait for the cp process to finish, do pipe-specific cleanup
 echo waiting for background cp to terminate...
@@ -29,5 +30,5 @@ rm -f rsyslog-testbench-fifo
 echo background cp has terminated, continue test...
 
 # and continue the usual checks
-source $srcdir/diag.sh seq-check 0 19999
-source $srcdir/diag.sh exit
+. $srcdir/diag.sh seq-check 0 19999
+. $srcdir/diag.sh exit
