@@ -1,3 +1,4 @@
+#!/bin/bash
 # This runs sends and receives messages via UDP to the standard
 # ports. Note that with UDP we can always have message loss. While this is
 # less likely in a local environment, we strongly limit the amount of data
@@ -10,4 +11,5 @@ echo \[sndrcv_udp.sh\]: testing sending and receiving via udp
 if [ "$EUID" -ne 0 ]; then
     exit 77 # Not root, skip this test
 fi
-source $srcdir/sndrcv_drvr.sh sndrcv_udp 50
+export TCPFLOOD_EXTRA_OPTS="-b1 -W1"
+. $srcdir/sndrcv_drvr.sh sndrcv_udp 50
