@@ -1,3 +1,4 @@
+#!/bin/bash
 # This runs sends and receives messages via UDP to the non-standard port 2514
 # Note that with UDP we can always have message loss. While this is
 # less likely in a local environment, we strongly limit the amount of data
@@ -7,4 +8,5 @@
 # This file is part of the rsyslog project, released  under GPLv3
 echo ===============================================================================
 echo \[sndrcv_udp_nonstdpt.sh\]: testing sending and receiving via udp
-source $srcdir/sndrcv_drvr.sh sndrcv_udp_nonstdpt 500
+export TCPFLOOD_EXTRA_OPTS="-b1 -W1"
+. $srcdir/sndrcv_drvr.sh sndrcv_udp_nonstdpt 500
