@@ -81,8 +81,9 @@ BEGINtryResume
 CODESTARTtryResume
 ENDtryResume
 
-BEGINdoAction
+BEGINdoAction_NoStrings
 CODESTARTdoAction
+	(void)pMsgData; /* Suppress compiler warning on unused var */
 	dbgprintf("\n");
 	iRet = RS_RET_DISCARDMSG;
 ENDdoAction
@@ -109,9 +110,9 @@ CODE_STD_STRING_REQUESTparseSelectorAct(0)
 
 	if(*p == '~') {
 		dbgprintf("discard\n");
-		errmsg.LogError(0, RS_RET_DEPRECATED, "warning: ~ action "
-			"is deprecated, consider using the 'stop' "
-			"statement instead");
+		errmsg.LogMsg(0, RS_RET_DEPRECATED, LOG_WARNING,
+			"warning: ~ action is deprecated, consider "
+			"using the 'stop' statement instead");
 	} else {
 		iRet = RS_RET_CONFLINE_UNPROCESSED;
 	}
