@@ -597,8 +597,7 @@ doZipFinish(wrkrInstanceData_t *pWrkrData)
 	if(!pWrkrData->bzInitDone)
 		goto done;
 
-// TODO: can we get this into a single common function?
-dbgprintf("DDDD: in doZipFinish()\n");
+	// TODO: can we get this into a single common function?
 	pWrkrData->zstrm.avail_in = 0;
 	/* run deflate() on buffer until everything has been compressed */
 	do {
@@ -634,10 +633,15 @@ static rsRetVal TCPSendFrame(void *pvData, char *msg, size_t len)
 	DBGPRINTF("omfwd: add %u bytes to send buffer (curr offs %u)\n",
 		(unsigned) len, pWrkrData->offsSndBuf);
 	if(pWrkrData->offsSndBuf != 0 && pWrkrData->offsSndBuf + len >= sizeof(pWrkrData->sndBuf)) {
-		/* no buffer space left, need to commit previous records */
+		/* no buffer space left, need to commit previous records. With the
+		 * current API, there unfortunately is no way to signal this
+		 * state transition to the upper layer.
+		 */
+		DBGPRINTF("omfwd: we need to do a tcp send due to buffer "
+			  "out of space. If the transaction fails, this will "
+			  "lead to duplication of messages");
 		CHKiRet(TCPSendBuf(pWrkrData, pWrkrData->sndBuf, pWrkrData->offsSndBuf, NO_FLUSH));
 		pWrkrData->offsSndBuf = 0;
-		iRet = RS_RET_PREVIOUS_COMMITTED;
 	}
 
 	/* check if the message is too large to fit into buffer */
@@ -777,14 +781,14 @@ finalize_it:
 
 BEGINtryResume
 CODESTARTtryResume
-	dbgprintf("DDDD: tryResume: pWrkrData %p\n", pWrkrData);
+	dbgprintf("omfwd: tryResume: pWrkrData %p\n", pWrkrData);
 	iRet = doTryResume(pWrkrData);
 ENDtryResume
 
 
 BEGINbeginTransaction
 CODESTARTbeginTransaction
-dbgprintf("omfwd: beginTransaction\n");
+	dbgprintf("omfwd: beginTransaction\n");
 	iRet = doTryResume(pWrkrData);
 ENDbeginTransaction
 
@@ -876,7 +880,6 @@ CODESTARTcommitTransaction
 			FINALIZE;
 	}
 
-dbgprintf("omfwd: endTransaction, offsSndBuf %u, iRet %d\n", pWrkrData->offsSndBuf, iRet);
 	if(pWrkrData->offsSndBuf != 0) {
 		iRet = TCPSendBuf(pWrkrData, pWrkrData->sndBuf, pWrkrData->offsSndBuf, IS_FLUSH);
 		pWrkrData->offsSndBuf = 0;
